# SAI

[![license](https://img.shields.io/badge/license-GPL%20v3-black.svg?style=flat-square)](LICENSE) 
[![language](http://img.shields.io/badge/language-Python-blue.svg?style=flat-square)](https://www.python.org/) 
[![build status](https://img.shields.io/github/actions/workflow/status/xin-huang/sai/build.yaml?branch=main&style=flat-square)](https://github.com/xin-huang/sai/actions)
[![codecov](https://img.shields.io/codecov/c/github/xin-huang/sai?style=flat-square)](https://app.codecov.io/gh/xin-huang/sai)
[![docs](https://img.shields.io/github/actions/workflow/status/xin-huang/sai/pages/pages-build-deployment?style=flat-square&label=docs)](https://github.com/xin-huang/sai/deployments/github-pages)

A Python Package for **S**tatistics for **A**daptive **I**ntrogression

The manual can be found [here](https://xin-huang.github.io/sai).
